# -*- coding: utf-8 -*-
#
# This file is execfile()d with the current directory set to its containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

import datetime
import sys

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
# sys.path.insert(0, os.path.abspath('.'))

# -- Hack for ReadTheDocs ------------------------------------------------------
# This hack is necessary since RTD does not issue `sphinx-apidoc` before running
# `sphinx-build -b html . _build/html`. See Issue:
# https://github.com/rtfd/readthedocs.org/issues/1139
# DON'T FORGET: Check the box "Install your project inside a virtualenv using
# setup.py install" in the RTD Advanced Settings.
import os

on_rtd = os.environ.get("READTHEDOCS", None) == "True"
if on_rtd:
    import inspect
    from sphinx.ext.apidoc import main

    __location__ = os.path.join(
        os.getcwd(), os.path.dirname(inspect.getfile(inspect.currentframe()))
    )

    output_dir = os.path.join(__location__, "../docs/api")
    module_dir = os.path.join(__location__, "../tsfresh")
    cmd_line_template = "sphinx-apidoc -f -o {outputdir} {moduledir}"
    cmd_line = cmd_line_template.format(outputdir=output_dir, moduledir=module_dir)
    main(cmd_line.split(" ")[1:])

# -- General configuration -----------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.intersphinx",
    "sphinx.ext.viewcode",
    "sphinx.ext.doctest",
    "sphinx.ext.imgmath",
    "sphinx.ext.napoleon",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix of source filenames.
source_suffix = ".rst"

# The encoding of source files.
# source_encoding = 'utf-8-sig'

# The master toctree document.
master_doc = "index"

# General information about the project.
now = datetime.datetime.today()
project = "tsfresh"
copyright = "2023-{}, Maximilian Christ et al./ Blue Yonder GmbH".format(now.year)

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = ""  # Is set by calling `setup.py docs`
# The full version, including alpha/beta/rc tags.
release = ""  # Is set by calling `setup.py docs`

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
# language = None

# There are two options for replacing |today|: either, you set today to some
# non-false value, then it is used:
# today = ''
# Else, today_fmt is used as the format for a strftime call.
# today_fmt = '%B %d, %Y'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = ["_build", "api/tests*"]

# Boolean indicating whether to scan all found documents for autosummary
# directives, and to generate stub pages for each
autosummary_generate = True

# -- Options for HTML output ---------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = "sphinx_rtd_theme"

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
html_theme_options = {"style_nav_header_background": "#51b63c"}

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
try:
    from tsfresh import __version__ as version
except ImportError:
    pass
else:
    release = version

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# From https://rackerlabs.github.io/docs-rackspace/tools/rtd-tables.html
html_css_files = [
    'theme_override.css',
]

# Output file base name for HTML help builder.
htmlhelp_basename = "tsfresh-doc"



# Testcase for benchmarking tsfresh feature extraction and selection
import numpy as np
import pandas as pd
import pytest

from tsfresh import extract_features, extract_relevant_features
from tsfresh.feature_extraction.settings import (
    ComprehensiveFCParameters,
    MinimalFCParameters,
)


def create_data(time_series_length, num_ids, random_seed=42):
    np.random.seed(random_seed)

    df = pd.concat(
        [
            pd.DataFrame(
                {
                    "id": [i] * time_series_length,
                    "time": range(time_series_length),
                    "value": np.random.randn(time_series_length).cumsum(),
                }
            )
            for i in range(num_ids)
        ]
    )

    return df


def test_benchmark_small_data(benchmark):
    df = create_data(5, 200)

    benchmark(
        extract_features,
        df,
        column_id="id",
        column_sort="time",
        n_jobs=0,
        disable_progressbar=True,
    )


def test_benchmark_large_data(benchmark):
    df = create_data(500, 20)

    benchmark(
        extract_features,
        df,
        column_id="id",
        column_sort="time",
        n_jobs=0,
        disable_progressbar=True,
    )


def test_benchmark_with_selection(benchmark):
    df = create_data(500, 20)
    y = pd.Series(np.random.choice([0, 1], 20))

    benchmark(
        extract_relevant_features,
        df,
        y,
        column_id="id",
        column_sort="time",
        n_jobs=0,
        disable_progressbar=True,
    )



# -*- coding: utf-8 -*-
# This file as well as the whole tsfresh package are licenced under the MIT licence (see the LICENCE.txt)
# Maximilian Christ (maximilianchrist.com), Blue Yonder Gmbh, 2016

import unittest

import dask.dataframe as dd
import numpy as np
import pandas as pd

from tsfresh import extract_features, extract_relevant_features
from tsfresh.examples.driftbif_simulation import load_driftbif, sample_tau, velocity
from tsfresh.feature_extraction import MinimalFCParameters


class DriftBifSimlationTestCase(unittest.TestCase):
    def setUp(self):
        np.random.seed(42)

    def test_intrinsic_velocity_at_default_bifurcation_point(self):
        """
        The intrinsic velocity of a dissipative soliton at the Drift bifurcation point is zero.
        """
        ds = velocity(tau=1.0 / 0.3)
        self.assertEqual(ds.deterministic, 0.0)

    def test_relaxation_dynamics(self):
        """
        Test accuracy of integrating the deterministic dynamics [6, p. 116]
        """
        ds = velocity(tau=1.01 / 0.3, R=0)
        v0 = 1.01 * ds.deterministic

        Nt = 100  # Number of time steps
        v = ds.simulate(Nt, v0=np.array([v0, 0.0]))

        k3t = ds.kappa_3 * ds.tau
        k3st = ds.kappa_3**2 * ds.tau
        a0 = v0 / ds.kappa_3

        def acceleration(t):
            return ds.kappa_3 * (
                a0
                * np.sqrt(k3t - 1)
                * np.exp(k3st * t)
                / np.sqrt(
                    np.exp(2.0 * k3st * t) * ds.Q * a0**2
                    + np.exp(2.0 * ds.kappa_3 * t) * (k3t - 1 - ds.Q * a0**2)
                )
            )

        t = ds.delta_t * np.arange(Nt)
        return np.testing.assert_array_almost_equal(
            v[:, 0], np.vectorize(acceleration)(t), decimal=8
        )

    def test_equlibrium_velocity(self):
        """
        Test accuracy of integrating the deterministic dynamics for equilibrium velocity [6, p. 116]
        """
        ds = velocity(tau=1.01 / 0.3, R=0)
        v0 = ds.deterministic

        Nt = 100  # Number of time steps
        v = ds.simulate(Nt, v0=np.array([v0, 0.0]))

        return np.testing.assert_array_almost_equal(
            v[:, 0] - v0, np.zeros(Nt), decimal=8
        )

    def test_dimensionality(self):
        ds = velocity(tau=1.0 / 0.3)
        Nt = 10
        v = ds.simulate(Nt)
        self.assertEqual(
            v.shape,
            (Nt, 2),
            "The default configuration should return velocities "
            "from a two-dimensional dissipative soliton.",
        )

        v = ds.simulate(Nt, v0=np.zeros(3))
        self.assertEqual(
            v.shape,
            (Nt, 3),
            "The returned vector should reflect the dimension of the initial condition.",
        )

    def test_relevant_feature_extraction(self):
        df, y = load_driftbif(100, 10, classification=False)

        df["id"] = df["id"].astype("str")
        y.index = y.index.astype("str")

        X = extract_relevant_features(
            df,
            y,
            column_id="id",
            column_sort="time",
            column_kind="dimension",
            column_value="value",
        )

        self.assertGreater(len(X.columns), 10)


class SampleTauTestCase(unittest.TestCase):
    def setUp(self):
        np.random.seed(42)

    def test_range(self):
        tau = sample_tau(100)
        self.assertGreaterEqual(min(tau), 2.87)
        self.assertLessEqual(max(tau), 3.8)

    def test_ratio(self):
        tau = sample_tau(100000, ratio=0.4)
        sample = np.array(tau)
        before = np.sum(sample <= 1 / 0.3)
        beyond = np.sum(sample > 1 / 0.3)
        self.assertTrue(abs(0.4 - float(before) / (before + beyond)) < 0.006)


class LoadDriftBifTestCase(unittest.TestCase):
    def setUp(self):
        np.random.seed(42)

    def test_classification_labels(self):
        X, y = load_driftbif(10, 100)
        self.assertEqual(set(y), {0, 1})

    def test_regression_labels(self):
        Nsamples = 10
        X, y = load_driftbif(Nsamples, 100, classification=False)
        self.assertEqual(
            y.size,
            np.unique(y).size,
            "For regression the target vector is expected to not contain any dublicated labels.",
        )

    def test_default_dimensionality(self):
        Nsamples = 10
        Nt = 100
        X, y = load_driftbif(Nsamples, Nt)
        self.assertEqual(X.shape, (2 * Nt * Nsamples, 4))

    def test_configured_dimensionality(self):
        Nsamples = 10
        Nt = 100
        X, y = load_driftbif(Nsamples, Nt, m=3)
        self.assertEqual(X.shape, (3 * Nt * Nsamples, 4))



# -*- coding: utf-8 -*-
# This file as well as the whole tsfresh package are licenced under the MIT licence (see the LICENCE.txt)
# Maximilian Christ (maximilianchrist.com), Blue Yonder Gmbh, 2016

from builtins import range
from unittest import TestCase

import numpy as np
import pandas as pd

from tsfresh.transformers.feature_selector import FeatureSelector


class FeatureSelectorTestCase(TestCase):
    def setUp(self):
        np.random.seed(0)

    def test_not_fitted(self):
        selector = FeatureSelector()

        X = pd.DataFrame()

        self.assertRaises(RuntimeError, selector.transform, X)

    def test_extract_relevant_features(self):
        selector = FeatureSelector()
        np.random.seed(42)
        y = pd.Series(np.random.binomial(1, 0.5, 1000))
        X = pd.DataFrame(index=list(range(1000)))

        z = y - np.random.binomial(1, 0.1, 1000) + np.random.binomial(1, 0.1, 1000)
        z[z == -1] = 0
        z[z == 2] = 1

        X["rel1"] = z
        X["rel2"] = y * np.abs(np.random.normal(0, 1, 1000)) + np.random.normal(
            0, 0.1, 1000
        )
        X["rel3"] = y + np.random.normal(0, 1, 1000)
        X["rel4"] = y**2 + np.random.normal(0, 1, 1000)
        X["rel5"] = np.sqrt(y) + np.random.binomial(2, 0.1, 1000)

        X["irr_constant"] = 1.113344

        X["irr1"] = np.random.normal(0, 1, 1000)
        X["irr2"] = np.random.poisson(1, 1000)
        X["irr3"] = np.random.binomial(1, 0.3, 1000)
        X["irr4"] = np.random.normal(0, 1, 1000)
        X["irr5"] = np.random.poisson(1, 1000)
        X["irr6"] = np.random.binomial(1, 0.3, 1000)
        X["irr7"] = np.random.normal(0, 1, 1000)
        X["irr8"] = np.random.poisson(1, 1000)
        X["irr9"] = np.random.binomial(1, 0.3, 1000)

        returned_selector = selector.fit(X, y)
        self.assertIs(returned_selector, selector)
        self.assertEqual(
            sorted(selector.relevant_features), ["rel1", "rel2", "rel3", "rel4", "rel5"]
        )

        new_X = X.copy()

        selected_X = selector.transform(new_X)

        self.assertEqual(
            sorted(selector.relevant_features), sorted(list(selected_X.columns))
        )
        self.assertEqual(len(selector.features), len(X.columns))

    def test_nothing_relevant(self):
        selector = FeatureSelector()

        y = pd.Series(np.random.binomial(1, 0.5, 1000))
        X = pd.DataFrame(index=list(range(1000)))

        X["irr1"] = np.random.normal(0, 1, 1000)
        X["irr2"] = np.random.normal(2, 1, 1000)

        selector.fit(X, y)

        transformed_X = selector.transform(X.copy())

        self.assertEqual(list(transformed_X.columns), [])
        self.assertEqual(list(transformed_X.index), list(X.index))

    def test_with_numpy_array(self):
        selector = FeatureSelector()

        y = pd.Series(np.random.binomial(1, 0.5, 1000))
        X = pd.DataFrame(index=list(range(1000)))

        X["irr1"] = np.random.normal(0, 1, 1000)
        X["rel1"] = y

        y_numpy = y.values
        X_numpy = X.values

        selector.fit(X, y)
        selected_X = selector.transform(X)

        selector.fit(X_numpy, y_numpy)
        selected_X_numpy = selector.transform(X_numpy)

        self.assertTrue((selected_X_numpy == selected_X.values).all())

        self.assertTrue(selected_X_numpy.shape, (1, 1000))

    def test_feature_importance(self):
        selector = FeatureSelector()
        self.assertIsNone(selector.feature_importances_)

        y = pd.Series(np.random.binomial(1, 0.5, 1000))
        X = pd.DataFrame(index=list(range(1000)))

        X["irr1"] = np.random.normal(0, 1, 1000)
        X["rel1"] = y

        selector.fit(X, y)

        self.assertEqual(selector.feature_importances_.shape, (2,))

    def test_feature_importance(self):
        selector = FeatureSelector()
        self.assertIsNone(selector.p_values)

        y = pd.Series(np.random.binomial(1, 0.5, 1000))
        X = pd.DataFrame(index=list(range(1000)))

        X["irr1"] = np.random.normal(0, 1, 1000)
        X["rel1"] = y

        selector.fit(X, y)

        self.assertEqual(selector.p_values.shape, (2,))
        np.testing.assert_almost_equal(
            selector.p_values, 1.0 - selector.feature_importances_
        )

    def test_multiclass_relevant_features_selected(self):
        y0 = np.zeros(100)
        y1 = np.repeat(1, 100)
        y2 = np.repeat(2, 100)
        y_multi = pd.Series(np.uint8(np.concatenate([y0, y1, y2])))
        X_multi = pd.DataFrame()
        X_multi["irrelevant"] = np.concatenate([np.zeros(298), np.array([0.01, -0.01])])
        X_multi["relevant"] = X_multi["irrelevant"].copy()
        X_multi["relevant"][y_multi == 0] = np.random.uniform(2, 3, 100)

        selector = FeatureSelector(
            multiclass=True, n_significant=3, ml_task="classification"
        )

        selector.fit(X_multi, y_multi)

        self.assertEqual(selector.relevant_features, ["relevant"])

    def test_multiclass_importance_p_values(self):
        y0 = np.zeros(100)
        y1 = np.repeat(1, 100)
        y2 = np.repeat(2, 100)
        y = pd.Series(np.uint8(np.concatenate([y0, y1, y2])))
        X = pd.DataFrame(index=list(range(300)))

        X["irr1"] = np.random.normal(0, 1, 300)
        X["rel1"] = y

        selector = FeatureSelector(
            multiclass=True,
            ml_task="classification",
            n_significant=2,
            multiclass_p_values="all",
        )
        selector.fit(X, y)

        self.assertEqual(selector.p_values.shape, (2, 3))
        self.assertEqual(selector.feature_importances_.shape, (2, 3))

        selector = FeatureSelector(
            multiclass=True,
            ml_task="classification",
            n_significant=2,
            multiclass_p_values="min",
        )
        selector.fit(X, y)

        self.assertEqual(selector.p_values.shape, (2,))
        self.assertEqual(selector.feature_importances_.shape, (2,))

    def test_multiclass_max_avg_p_values(self):
        y0 = np.zeros(100)
        y1 = np.repeat(1, 100)
        y2 = np.repeat(2, 100)
        y = pd.Series(np.uint8(np.concatenate([y0, y1, y2])))
        X = pd.DataFrame(index=list(range(300)))

        X["irr1"] = np.random.normal(0, 1, 300)
        X["rel1"] = y

        selector = FeatureSelector(
            multiclass=True,
            ml_task="classification",
            n_significant=2,
            multiclass_p_values="max",
        )
        selector.fit(X, y)

        assert (selector.p_values > 0.1).all()
        selector = FeatureSelector(
            multiclass=True,
            ml_task="classification",
            n_significant=2,
            multiclass_p_values="avg",
        )
        selector.fit(X, y)

        assert (selector.p_values > 0.1).all()



# -*- coding: utf-8 -*-
# This file as well as the whole tsfresh package are licenced under the MIT licence (see the LICENCE.txt)
# Maximilian Christ (maximilianchrist.com), Blue Yonder Gmbh, 2016

import mock
import numpy as np
import pandas as pd
from sklearn import model_selection
from sklearn.ensemble import RandomForestClassifier
from sklearn.pipeline import Pipeline

from tests.fixtures import DataTestCase, warning_free
from tsfresh.feature_extraction import MinimalFCParameters
from tsfresh.transformers.relevant_feature_augmenter import RelevantFeatureAugmenter


class RelevantFeatureAugmenterTestCase(DataTestCase):
    def setUp(self):
        self.test_df = self.create_test_data_sample()
        fc_parameters = {"length": None}
        self.kind_to_fc_parameters = {
            "a": fc_parameters.copy(),
            "b": fc_parameters.copy(),
        }

    def test_not_fitted(self):
        augmenter = RelevantFeatureAugmenter()

        X = pd.DataFrame()

        self.assertRaises(RuntimeError, augmenter.transform, X)

    def test_no_timeseries(self):
        augmenter = RelevantFeatureAugmenter()

        X = pd.DataFrame()
        y = pd.Series(dtype="float64")

        self.assertRaises(RuntimeError, augmenter.fit, X, y)
        self.assertRaises(RuntimeError, augmenter.fit_transform, X, y)

    def test_nothing_relevant(self):
        augmenter = RelevantFeatureAugmenter(
            kind_to_fc_parameters=self.kind_to_fc_parameters,
            column_value="val",
            column_id="id",
            column_sort="sort",
            column_kind="kind",
        )

        y = pd.Series({10: 1, 500: 0})
        X = pd.DataFrame(index=[10, 500])

        augmenter.set_timeseries_container(self.test_df)
        augmenter.fit(X, y)
        transformed_X = augmenter.transform(X.copy())

        fit_transformed_X = augmenter.fit_transform(X, y)

        self.assertEqual(list(transformed_X.columns), [])
        self.assertEqual(list(transformed_X.index), list(X.index))
        self.assertEqual(list(fit_transformed_X.columns), [])
        self.assertEqual(list(fit_transformed_X.index), list(X.index))

    def test_filter_only_tsfresh_features_true(self):
        """
        The boolean flag `filter_only_tsfresh_features` makes sure that only the time series based features are
        filtered. This unit tests checks that
        """

        augmenter = RelevantFeatureAugmenter(
            kind_to_fc_parameters=self.kind_to_fc_parameters,
            filter_only_tsfresh_features=True,
            column_value="val",
            column_id="id",
            column_sort="sort",
            column_kind="kind",
        )

        y = pd.Series({10: 1, 500: 0})
        X = pd.DataFrame(index=[10, 500])
        X["pre_feature"] = 0

        augmenter.set_timeseries_container(self.test_df)
        augmenter.fit(X, y)
        transformed_X = augmenter.transform(X.copy())

        fit_transformed_X = augmenter.fit_transform(X, y)

        self.assertEqual(
            sum(["pre_feature" == column for column in transformed_X.columns]), 1
        )
        self.assertEqual(
            sum(["pre_feature" == column for column in fit_transformed_X.columns]), 1
        )

    def test_filter_only_tsfresh_features_false(self):
        """
        The boolean flag `filter_only_tsfresh_features` makes sure that only the time series based features are
        filtered. This unit tests checks that
        """

        augmenter = RelevantFeatureAugmenter(
            kind_to_fc_parameters=self.kind_to_fc_parameters,
            filter_only_tsfresh_features=False,
            column_value="val",
            column_id="id",
            column_sort="sort",
            column_kind="kind",
        )

        df, y = self.create_test_data_sample_with_target()
        X = pd.DataFrame(index=np.unique(df.id))
        X["pre_drop"] = 0
        X["pre_keep"] = y

        augmenter.set_timeseries_container(df)
        augmenter.fit(X, y)
        transformed_X = augmenter.transform(X.copy())

        fit_transformed_X = augmenter.fit_transform(X, y)

        self.assertEqual(
            sum(["pre_keep" == column for column in transformed_X.columns]), 1
        )
        self.assertEqual(
            sum(["pre_drop" == column for column in transformed_X.columns]), 0
        )
        self.assertEqual(
            sum(["pre_keep" == column for column in fit_transformed_X.columns]), 1
        )
        self.assertEqual(
            sum(["pre_drop" == column for column in fit_transformed_X.columns]), 0
        )

    @mock.patch("tsfresh.transformers.feature_selector.calculate_relevance_table")
    def test_does_impute(self, calculate_relevance_table_mock):
        df = pd.DataFrame([[1, 1, 1], [2, 1, 1]], columns=["id", "time", "value"])
        X = pd.DataFrame(index=[1])
        y = pd.Series([0, 1])
        fc_parameters = {"autocorrelation": [{"lag": 2}]}

        calculate_relevance_table_mock.return_value = pd.DataFrame(
            columns=["feature", "p_value", "relevant"]
        )
        augmenter = RelevantFeatureAugmenter(
            column_id="id", column_sort="time", default_fc_parameters=fc_parameters
        )
        augmenter.set_timeseries_container(df)
        with warning_free():
            augmenter.fit(X, y)

        assert calculate_relevance_table_mock.call_count == 1
        assert not calculate_relevance_table_mock.call_args[0][0].isnull().any().any()

    def test_no_ids_present(self):
        augmenter = RelevantFeatureAugmenter(
            kind_to_fc_parameters=self.kind_to_fc_parameters,
            filter_only_tsfresh_features=False,
            column_value="val",
            column_id="id",
            column_sort="sort",
            column_kind="kind",
        )

        df, y = self.create_test_data_sample_with_target()
        X_with_wrong_ids = pd.DataFrame(index=[-999])

        augmenter.set_timeseries_container(df)

        self.assertRaisesRegex(
            AttributeError,
            r"The ids of the time series container",
            augmenter.fit,
            X_with_wrong_ids,
            y,
        )
        self.assertRaisesRegex(
            AttributeError,
            r"The ids of the time series container",
            augmenter.fit_transform,
            X_with_wrong_ids,
            y,
        )

    def test_multiclass_selection(self):
        augmenter = RelevantFeatureAugmenter(
            column_value="val",
            column_id="id",
            column_sort="sort",
            column_kind="kind",
            multiclass=True,
            n_significant=3,
        )

        df, y = self.create_test_data_sample_with_multiclass_target()
        X = pd.DataFrame(index=np.unique(df.id))

        augmenter.set_timeseries_container(df)
        fit_transformed_X = augmenter.fit_transform(X, y)

        self.assertEqual(len(fit_transformed_X.columns), 4)


def test_relevant_augmentor_cross_validated():
    """
    Validates that the RelevantFeatureAugmenter can be cloned in pipelines, see issue 537
    """
    n = 16  # number of samples, needs to be divisable by 4
    index = range(n)
    df_ts = pd.DataFrame(
        {
            "time": [10, 11] * n,
            "id": np.repeat(index, 2),
            "value": [0, 1] * (n // 4)
            + [1, 2] * (n // 4)
            + [10, 11] * (n // 4)  # class 0
            + [12, 14] * (n // 4),
        }
    )
    y = pd.Series(data=[0] * (n // 2) + [1] * (n // 2), index=index)
    X = pd.DataFrame(index=index)
    augmenter = RelevantFeatureAugmenter(
        column_id="id",
        column_sort="time",
        timeseries_container=df_ts,
        default_fc_parameters=MinimalFCParameters(),
        disable_progressbar=True,
        show_warnings=False,
        fdr_level=0.90,
    )
    pipeline = Pipeline(
        [
            ("augmenter", augmenter),
            ("classifier", RandomForestClassifier(random_state=1)),
        ]
    )

    scores = model_selection.cross_val_score(pipeline, X, y, cv=2)
    assert (scores == np.array([1, 1])).all()
